==> hadoop-3.2.3-src.tar.gz: hadoop-3.2.3-src/hadoop-hdfs-project/hadoop-hdfs-rbf/src/main/java/org/apache/hadoop/hdfs/server/federation/store/protocol/impl/pb/RouterHeartbeatRequestPBImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hdfs.server.federation.store.protocol.impl.pb;

import java.io.IOException;

import org.apache.hadoop.hdfs.federation.protocol.proto.HdfsServerFederationProtos.RouterHeartbeatRequestProto;
import org.apache.hadoop.hdfs.federation.protocol.proto.HdfsServerFederationProtos.RouterHeartbeatRequestProto.Builder;
import org.apache.hadoop.hdfs.federation.protocol.proto.HdfsServerFederationProtos.RouterHeartbeatRequestProtoOrBuilder;
import org.apache.hadoop.hdfs.federation.protocol.proto.HdfsServerFederationProtos.RouterRecordProto;
import org.apache.hadoop.hdfs.server.federation.store.protocol.RouterHeartbeatRequest;
import org.apache.hadoop.hdfs.server.federation.store.records.RouterState;
import org.apache.hadoop.hdfs.server.federation.store.records.impl.pb.PBRecord;
import org.apache.hadoop.hdfs.server.federation.store.records.impl.pb.RouterStatePBImpl;

import com.google.protobuf.Message;

/**
 * Protobuf implementation of the state store API object
 * RouterHeartbeatRequest.
 */
public class RouterHeartbeatRequestPBImpl extends RouterHeartbeatRequest
    implements PBRecord {

  private FederationProtocolPBTranslator<RouterHeartbeatRequestProto, Builder,
      RouterHeartbeatRequestProtoOrBuilder> translator =
          new FederationProtocolPBTranslator<RouterHeartbeatRequestProto,
              Builder, RouterHeartbeatRequestProtoOrBuilder>(
                  RouterHeartbeatRequestProto.class);

  public RouterHeartbeatRequestPBImpl() {
  }

  @Override
  public RouterHeartbeatRequestProto getProto() {
    return this.translator.build();
  }

  @Override
  public void setProto(Message proto) {
    this.translator.setProto(proto);
  }

  @Override
  public void readInstance(String base64String) throws IOException {
    this.translator.readInstance(base64String);
  }

  @Override
  public RouterState getRouter() throws IOException {
    RouterRecordProto routerProto =
        this.translator.getProtoOrBuilder().getRouter();
    return new RouterStatePBImpl(routerProto);
  }

  @Override
  public void setRouter(RouterState routerState) {
    if (routerState instanceof RouterStatePBImpl) {
      RouterStatePBImpl routerStatePB = (RouterStatePBImpl)routerState;
      this.translator.getBuilder().setRouter(routerStatePB.getProto());
    }
  }
}

==> hadoop-3.4.1-src.tar.gz: hadoop-3.4.1-src/hadoop-hdfs-project/hadoop-hdfs-rbf/src/main/java/org/apache/hadoop/hdfs/server/federation/store/protocol/impl/pb/RouterHeartbeatRequestPBImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hdfs.server.federation.store.protocol.impl.pb;

import java.io.IOException;

import org.apache.hadoop.hdfs.federation.protocol.proto.HdfsServerFederationProtos.RouterHeartbeatRequestProto;
import org.apache.hadoop.hdfs.federation.protocol.proto.HdfsServerFederationProtos.RouterHeartbeatRequestProto.Builder;
import org.apache.hadoop.hdfs.federation.protocol.proto.HdfsServerFederationProtos.RouterHeartbeatRequestProtoOrBuilder;
import org.apache.hadoop.hdfs.federation.protocol.proto.HdfsServerFederationProtos.RouterRecordProto;
import org.apache.hadoop.hdfs.server.federation.store.protocol.RouterHeartbeatRequest;
import org.apache.hadoop.hdfs.server.federation.store.records.RouterState;
import org.apache.hadoop.hdfs.server.federation.store.records.impl.pb.PBRecord;
import org.apache.hadoop.hdfs.server.federation.store.records.impl.pb.RouterStatePBImpl;

import org.apache.hadoop.thirdparty.protobuf.Message;

/**
 * Protobuf implementation of the state store API object
 * RouterHeartbeatRequest.
 */
public class RouterHeartbeatRequestPBImpl extends RouterHeartbeatRequest
    implements PBRecord {

  private FederationProtocolPBTranslator<RouterHeartbeatRequestProto, Builder,
      RouterHeartbeatRequestProtoOrBuilder> translator =
          new FederationProtocolPBTranslator<RouterHeartbeatRequestProto,
              Builder, RouterHeartbeatRequestProtoOrBuilder>(
                  RouterHeartbeatRequestProto.class);

  public RouterHeartbeatRequestPBImpl() {
  }

  @Override
  public RouterHeartbeatRequestProto getProto() {
    return this.translator.build();
  }

  @Override
  public void setProto(Message proto) {
    this.translator.setProto(proto);
  }

  @Override
  public void readInstance(String base64String) throws IOException {
    this.translator.readInstance(base64String);
  }

  @Override
  public RouterState getRouter() throws IOException {
    RouterRecordProto routerProto =
        this.translator.getProtoOrBuilder().getRouter();
    return new RouterStatePBImpl(routerProto);
  }

  @Override
  public void setRouter(RouterState routerState) {
    if (routerState instanceof RouterStatePBImpl) {
      RouterStatePBImpl routerStatePB = (RouterStatePBImpl)routerState;
      this.translator.getBuilder().setRouter(routerStatePB.getProto());
    }
  }
}
